==> eam-wshub-proxyclient-11.4-6-sources.jar: net/datastream/schemas/mp_functions/mp0113_001/DocumentAssociationMetaData.java <==

package net.datastream.schemas.mp_functions.mp0113_001;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_functions/MP0113_001}Join" maxOccurs="8" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="entity" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       &lt;attribute name="relationship" type="{http://schemas.datastream.net/MP_fields}CODE1_Type" />
 *       &lt;attribute name="columnPrefix" type="{http://www.w3.org/2001/XMLSchema}string" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "join"
})
@XmlRootElement(name = "DocumentAssociationMetaData")
public class DocumentAssociationMetaData {

    @XmlElement(name = "Join")
    protected List<Join> join;
    @XmlAttribute(name = "entity")
    protected String entity;
    @XmlAttribute(name = "relationship")
    protected String relationship;
    @XmlAttribute(name = "columnPrefix")
    protected String columnPrefix;

    /**
     * Gets the value of the join property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the join property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getJoin().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link Join }
     * 
     * 
     */
    public List<Join> getJoin() {
        if (join == null) {
            join = new ArrayList<Join>();
        }
        return this.join;
    }

    /**
     * Obtient la valeur de la propriété entity.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getEntity() {
        return entity;
    }

    /**
     * Définit la valeur de la propriété entity.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setEntity(String value) {
        this.entity = value;
    }

    /**
     * Obtient la valeur de la propriété relationship.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getRelationship() {
        return relationship;
    }

    /**
     * Définit la valeur de la propriété relationship.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setRelationship(String value) {
        this.relationship = value;
    }

    /**
     * Obtient la valeur de la propriété columnPrefix.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getColumnPrefix() {
        return columnPrefix;
    }

    /**
     * Définit la valeur de la propriété columnPrefix.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setColumnPrefix(String value) {
        this.columnPrefix = value;
    }

}

==> eam-wshub-proxyclient-11.7-4-sources.jar: net/datastream/schemas/mp_functions/mp0113_001/DocumentAssociationMetaData.java <==

package net.datastream.schemas.mp_functions.mp0113_001;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_functions/MP0113_001}Join" maxOccurs="8" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="entity" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       &lt;attribute name="relationship" type="{http://schemas.datastream.net/MP_fields}CODE1_Type" />
 *       &lt;attribute name="columnPrefix" type="{http://www.w3.org/2001/XMLSchema}string" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "join"
})
@XmlRootElement(name = "DocumentAssociationMetaData")
public class DocumentAssociationMetaData {

    @XmlElement(name = "Join")
    protected List<Join> join;
    @XmlAttribute(name = "entity")
    protected String entity;
    @XmlAttribute(name = "relationship")
    protected String relationship;
    @XmlAttribute(name = "columnPrefix")
    protected String columnPrefix;

    /**
     * Gets the value of the join property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the join property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getJoin().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link Join }
     * 
     * 
     */
    public List<Join> getJoin() {
        if (join == null) {
            join = new ArrayList<Join>();
        }
        return this.join;
    }

    /**
     * Gets the value of the entity property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getEntity() {
        return entity;
    }

    /**
     * Sets the value of the entity property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setEntity(String value) {
        this.entity = value;
    }

    /**
     * Gets the value of the relationship property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getRelationship() {
        return relationship;
    }

    /**
     * Sets the value of the relationship property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setRelationship(String value) {
        this.relationship = value;
    }

    /**
     * Gets the value of the columnPrefix property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getColumnPrefix() {
        return columnPrefix;
    }

    /**
     * Sets the value of the columnPrefix property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setColumnPrefix(String value) {
        this.columnPrefix = value;
    }

}
